package cn.com.countrygarden.bi.main.service.wcx;

import cn.com.countrygarden.bi.main.dto.wcx.WcxInnovationDto;
import cn.com.countrygarden.bi.main.dto.wcx.WcxReportDto;
import cn.com.countrygarden.bi.main.model.PageData;

import java.util.List;

/**
 * 微创新报表
 * Created by ADMS on 2018/8/14.
 */
public interface WcxReportService {
    /**
     * 分页查询项目报表
     * @param condition
     * @return
     */
    PageData selectProjectReportPageData(WcxInnovationDto condition);

    /**
     * 分页查询区域报表列表展示
     * @param condition
     * @return
     */
    PageData selectRegionReportPageData(WcxInnovationDto condition);

    /**
     * 查询区域报表
     * @param condition
     * @return
     */
    List<WcxReportDto> selectRegionReportList(WcxInnovationDto condition);

    /**
     * 查询项目报表
     * @param condition
     * @return
     */
    List<WcxReportDto> selectProjectReportList(WcxInnovationDto condition);

    /**
     * 查询各基础业务线报表
     * @param condition
     * @return
     */
    PageData selectBaselineReportPageData(WcxInnovationDto condition);

    /**
     * 查询列表
     * @param condition
     * pageSize 为-1 查询所有内容
     * @return
     */
    List<WcxReportDto> selectBaselineReportList(WcxInnovationDto condition);
}
